Package: chk
Title: Check User-Supplied Function Arguments
Version: 0.10.0
Authors@R: c(
    person("Joe", "Thorley", , "joe@poissonconsulting.ca", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-7683-4592")),
    person("Kirill", "Müller", role = "aut",
           comment = c(ORCID = "0000-0002-1416-3412")),
    person("Ayla", "Pearson", role = "aut",
           comment = c(ORCID = "0000-0001-7388-1222")),
    person("Florencia", "D'Andrea", role = "ctb"),
    person("Nadine", "Hussein", , "nadine@poissonconsulting.ca", role = "ctb",
           comment = c(ORCID = "0000-0003-4470-8361")),
    person("Evan", "Amies-Galonski", , "evan@poissonconsulting.ca", role = "ctb",
           comment = c(ORCID = "0000-0003-1096-2089")),
    person("Poisson Consulting", role = c("cph", "fnd"))
  )
Description: For developers to check user-supplied function arguments.  It
    is designed to be simple, fast and customizable.  Error messages
    follow the tidyverse style guide.
License: MIT + file LICENSE
URL: https://github.com/poissonconsulting/chk,
        https://poissonconsulting.github.io/chk/
BugReports: https://github.com/poissonconsulting/chk/issues/
Depends: R (>= 3.6)
Imports: lifecycle, methods, rlang, tools
Suggests: covr, knitr, rmarkdown, testthat (>= 3.0.0), withr
VignetteBuilder: knitr
RdMacros: lifecycle
Config/Needs/website: poissonconsulting/poissontemplate
Config/testthat/edition: 3
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.2.9000
NeedsCompilation: no
Packaged: 2025-01-24 19:31:20 UTC; joe
Author: Joe Thorley [aut, cre] (<https://orcid.org/0000-0002-7683-4592>),
  Kirill Müller [aut] (<https://orcid.org/0000-0002-1416-3412>),
  Ayla Pearson [aut] (<https://orcid.org/0000-0001-7388-1222>),
  Florencia D'Andrea [ctb],
  Nadine Hussein [ctb] (<https://orcid.org/0000-0003-4470-8361>),
  Evan Amies-Galonski [ctb] (<https://orcid.org/0000-0003-1096-2089>),
  Poisson Consulting [cph, fnd]
Maintainer: Joe Thorley <joe@poissonconsulting.ca>
Repository: CRAN
Date/Publication: 2025-01-24 21:20:05 UTC
Built: R 4.6.0; ; 2026-04-27 05:39:31 UTC; unix
