# Generated by roxygen2: do not edit by hand

export(abort_chk)
export(backtick_chk)
export(cc)
export(check_data)
export(check_dim)
export(check_dirs)
export(check_files)
export(check_key)
export(check_length)
export(check_names)
export(check_values)
export(chk_all)
export(chk_all_equal)
export(chk_all_equivalent)
export(chk_all_identical)
export(chk_array)
export(chk_atomic)
export(chk_character)
export(chk_character_or_factor)
export(chk_chr)
export(chk_compatible_lengths)
export(chk_complex)
export(chk_complex_number)
export(chk_count)
export(chk_data)
export(chk_date)
export(chk_date_time)
export(chk_datetime)
export(chk_dbl)
export(chk_dir)
export(chk_dirs)
export(chk_double)
export(chk_environment)
export(chk_equal)
export(chk_equivalent)
export(chk_ext)
export(chk_factor)
export(chk_false)
export(chk_file)
export(chk_files)
export(chk_flag)
export(chk_function)
export(chk_gt)
export(chk_gte)
export(chk_has)
export(chk_identical)
export(chk_in)
export(chk_integer)
export(chk_is)
export(chk_join)
export(chk_length)
export(chk_lgl)
export(chk_list)
export(chk_logical)
export(chk_lt)
export(chk_lte)
export(chk_match)
export(chk_matrix)
export(chk_missing)
export(chk_named)
export(chk_no_missing)
export(chk_not_any_na)
export(chk_not_empty)
export(chk_not_missing)
export(chk_not_null)
export(chk_not_subset)
export(chk_null)
export(chk_null_or)
export(chk_number)
export(chk_numeric)
export(chk_off)
export(chk_on)
export(chk_orderset)
export(chk_proportion)
export(chk_range)
export(chk_raw)
export(chk_s3_class)
export(chk_s4_class)
export(chk_scalar)
export(chk_setequal)
export(chk_sorted)
export(chk_string)
export(chk_subset)
export(chk_superset)
export(chk_true)
export(chk_tz)
export(chk_unique)
export(chk_unused)
export(chk_used)
export(chk_valid_name)
export(chk_vector)
export(chk_whole_number)
export(chk_whole_numeric)
export(chk_wnum)
export(chkor)
export(chkor_vld)
export(deparse_backtick)
export(deparse_backtick_chk)
export(err)
export(expect_chk_error)
export(is_chk_on)
export(message_chk)
export(msg)
export(p)
export(p0)
export(unbacktick_chk)
export(vld_all)
export(vld_all_equal)
export(vld_all_equivalent)
export(vld_all_identical)
export(vld_array)
export(vld_atomic)
export(vld_character)
export(vld_character_or_factor)
export(vld_chr)
export(vld_compatible_lengths)
export(vld_complex)
export(vld_complex_number)
export(vld_count)
export(vld_data)
export(vld_date)
export(vld_date_time)
export(vld_datetime)
export(vld_dbl)
export(vld_dir)
export(vld_double)
export(vld_environment)
export(vld_equal)
export(vld_equivalent)
export(vld_ext)
export(vld_factor)
export(vld_false)
export(vld_file)
export(vld_flag)
export(vld_function)
export(vld_gt)
export(vld_gte)
export(vld_identical)
export(vld_integer)
export(vld_is)
export(vld_join)
export(vld_length)
export(vld_lgl)
export(vld_list)
export(vld_logical)
export(vld_lt)
export(vld_lte)
export(vld_match)
export(vld_matrix)
export(vld_missing)
export(vld_named)
export(vld_no_missing)
export(vld_not_any_na)
export(vld_not_empty)
export(vld_not_missing)
export(vld_not_null)
export(vld_not_subset)
export(vld_null)
export(vld_number)
export(vld_numeric)
export(vld_orderset)
export(vld_range)
export(vld_raw)
export(vld_s3_class)
export(vld_s4_class)
export(vld_scalar)
export(vld_setequal)
export(vld_sorted)
export(vld_string)
export(vld_subset)
export(vld_superset)
export(vld_true)
export(vld_tz)
export(vld_unique)
export(vld_unused)
export(vld_used)
export(vld_valid_name)
export(vld_vector)
export(vld_whole_number)
export(vld_whole_numeric)
export(vld_wnum)
export(wrn)
import(lifecycle)
import(rlang)
importFrom(lifecycle,deprecated)
