% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/chk-null-or.R
\name{chk_null_or}
\alias{chk_null_or}
\title{Check NULL Or}
\usage{
chk_null_or(x, chk, ..., vld, x_name = NULL)
}
\arguments{
\item{x}{The object to check.}

\item{chk}{A chk function. Soft-deprecated for vld. \ifelse{html}{\href{https://lifecycle.r-lib.org/articles/stages.html#deprecated}{\figure{lifecycle-deprecated.svg}{options: alt='[Deprecated]'}}}{\strong{[Deprecated]}}}

\item{...}{Arguments passed to chk.}

\item{vld}{A vld function.}

\item{x_name}{A string of the name of object x or NULL.}
}
\value{
An informative error if the test fails.
}
\description{
Checks if NULL or passes test.
}
\examples{
chk_null_or(NULL, chk_number)
chk_null_or(1, chk_number)
try(chk_null_or("1", chk_number))
}
